]> Dogcows Code - chaz/rasterize/blobdiff - raster.h
refactor triangle group into a separate class
[chaz/rasterize] / raster.h
index 1d43132c6ce7fe40a62b5c8566d589ba195656ea..53f7627a65a5b43d1c94b47725bf046643a7f5a8 100644 (file)
--- a/raster.h
+++ b/raster.h
@@ -11,6 +11,7 @@
 #include "color.h"
 #include "common.h"
 #include "light.h"
+#include "model.h"
 #include "tri.h"
 
 
@@ -102,7 +103,12 @@ int raster_export_bmp(const raster_t* p, const char* filename);
 void raster_clear(raster_t* p, color_t fill);
 
 /*
- * Draw a smooth gradient triangle to the raster.
+ * Draw a model to the raster.
+ */
+void raster_draw_model(raster_t* p, const model_t* model);
+
+/*
+ * Draw a triangle to the raster.
  */
 void raster_draw_tri(raster_t* p, const tri_t* triangle);
 
This page took 0.019527 seconds and 4 git commands to generate.